@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import logging
+from typing import List
 
 from dynamicprompts.wildcardmanager import WildcardManager
 from dynamicprompts import constants
@@ -15,7 +16,7 @@ class CombinatorialPromptGenerator(PromptGenerator):
         self._wildcard_manager = wildcard_manager
         self._generator = CombinatorialGenerator(wildcard_manager)
 
-    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> list[str]:
+    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> List[str]:
         if template is None or len(template) == 0:
             return [""]
         prompts = self._generator.generate_prompts(template, max_prompts)
