@@ -1,8 +1,9 @@
 from __future__ import annotations
+from typing import List
 
 from .promptgenerator import PromptGenerator
 
 
 class DummyGenerator(PromptGenerator):
-    def generate(self, template, num_images) -> list[str]:
+    def generate(self, template, num_images) -> List[str]:
         return num_images * [template]
